@@ -1,6 +1,8 @@
-import stjames
 import time
-from typing import Optional
+from typing import Any
+
+import stjames
+
 from .workflow import Workflow
 
 """ A high-level interface to submitting a calculation. """
@@ -10,15 +12,26 @@ def compute(
     molecule: str | stjames.Molecule,
     workflow_type: str,
     name: str = "",
-    folder_uuid: Optional[stjames.UUID] = None,
+    folder_uuid: stjames.UUID | None = None,
     blocking: bool = True,
     ping_interval: int = 5,
     **workflow_data,
-) -> dict:
-    """High-level function to compute and return workflows."""
+) -> dict[str, Any]:
+    """
+    High-level function to compute and return workflows.
+
+    :param molecule: Molecule to compute
+    :param workflow_type: name of workflow to compute
+    :param name: name for the job
+    :param folder_uuid: folder to store the job
+    :param blocking: whether to wait for the job to finish
+    :param ping_interval: interval to check if the job is finished
+    :param workflow_data: additional data to pass to the workflow
+    :return: result of the workflow
+    """
 
     if isinstance(molecule, str):
-        stjmol = stjames.Molecule.from_smiles(molecule) 
+        stjmol = stjames.Molecule.from_smiles(molecule)
     elif isinstance(molecule, stjames.Molecule):
         stjmol = molecule
     else:
@@ -34,12 +47,9 @@ def compute(
 
     if blocking:
         uuid = result["uuid"]
-
         while not Workflow.is_finished(uuid):
             time.sleep(ping_interval)
 
-        completed_result = Workflow.retrieve(uuid)
-        return completed_result
+        return Workflow.retrieve(uuid)
 
-    else:
-        return result
+    return result
